macro_rules! export_agent_tool {
($plugin:ty $(,)?) => { ... };
}Expand description
Exports one typed Agent Tool from the same source as Wasm or Process.
macro_rules! export_agent_tool {
($plugin:ty $(,)?) => { ... };
}Exports one typed Agent Tool from the same source as Wasm or Process.