Dependencies

Struct Dependencies 

pub struct Dependencies { /* private fields */ }
Exact dependency routes selected for one Plugin generation.

Implementations

Source

impl Dependencies

pub fn one(&self, requirement_id: &str) -> Result<Dependency, String>

Resolves exactly one provider for a named dependency role.

pub fn optional( &self, requirement_id: &str, ) -> Result<Option<Dependency>, String>

Resolves zero or one provider for a named dependency role.

pub fn many(&self, requirement_id: &str) -> Vec<Dependency>

Resolves all providers for a named dependency role in Plan order.