pub struct Dependencies { /* private fields */ }Expand description
Exact dependency routes selected for one Plugin generation.
Implementations
Sourceimpl Dependencies
impl Dependencies
Sourcepub fn one(&self, requirement_id: &str) -> Result<Dependency, String>
pub fn one(&self, requirement_id: &str) -> Result<Dependency, String>
Resolves exactly one provider for a named dependency role.
Sourcepub fn optional(
&self,
requirement_id: &str,
) -> Result<Option<Dependency>, String>
pub fn optional( &self, requirement_id: &str, ) -> Result<Option<Dependency>, String>
Resolves zero or one provider for a named dependency role.
Sourcepub fn many(&self, requirement_id: &str) -> Vec<Dependency>
pub fn many(&self, requirement_id: &str) -> Vec<Dependency>
Resolves all providers for a named dependency role in Plan order.